@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '0.558';
+our $VERSION = '0.559';
 use Exporter 'import';
 our @EXPORT_OK = qw( read_line );
 
@@ -271,10 +271,7 @@ sub __init_readline {
         print clear_screen();
     }
     if ( length $self->{info} ) {
-        my $info_w = $term_w;
-        if ( $^O ne 'MSWin32' && $^O ne 'cygwin' ) {
-            $info_w += WIDTH_CURSOR;
-        }
+        my $info_w = $term_w + EXTRA_W;
         my @info = line_fold( $self->{info}, $info_w, { color => $self->{color}, join => 0 } );
         $self->{i}{info_row_count} = @info;
         if ( $self->{clear_screen} == 2 ) {
@@ -352,7 +349,7 @@ sub readline {
         }
     }
     $self->__modify_readline_options();
-    if ( $^O eq "MSWin32" ) {
+    if ( $^O eq 'MSWin32' ) {
         print $self->{codepage_mapping} ? "\e(K" : "\e(U";
     }
     local $| = 1;
@@ -483,7 +480,7 @@ Term::Form::ReadLine - Read a line from STDIN.
 
 =head1 VERSION
 
-Version 0.558
+Version 0.559
 
 =cut
 
@@ -675,7 +672,7 @@ L<stackoverflow|http://stackoverflow.com> for the help.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2022-2024 Matthäus Kiem.
+Copyright 2022-2025 Matthäus Kiem.
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
 details, see the full text of the licenses in the file LICENSE.
